#!/bin/bash
#
# Generates a new SELinux policy for the Agent Proxy.
#
# For usage examples, see: https://docs.aembit.io/features/selinux
# Requires packages: selinux-policy-devel

sepolicy generate --init AEMBIT_AGENT_PROXY_INSTALL_DIR_BIN/aembit_agent_proxy || exit 1
